Module: Unmagic

Defined in:
lib/unmagic/browser.rb,
lib/unmagic/browser.rb,
lib/unmagic/browser/error.rb,
lib/unmagic/browser/driver.rb,
lib/unmagic/browser/console.rb,
lib/unmagic/browser/element.rb,
lib/unmagic/browser/locator.rb,
lib/unmagic/browser/session.rb,
lib/unmagic/browser/version.rb,
lib/unmagic/browser/failures.rb,
lib/unmagic/browser/markdown.rb,
lib/unmagic/browser/emulation.rb,
lib/unmagic/browser/driver/base.rb,
lib/unmagic/browser/driver/local.rb,
lib/unmagic/browser/configuration.rb,
lib/unmagic/browser/driver/remote.rb,
lib/unmagic/browser/console/banner.rb,
lib/unmagic/browser/console/prompt.rb,
lib/unmagic/browser/console/values.rb,
lib/unmagic/browser/console/helpers.rb,
lib/unmagic/browser/console/graphics.rb,
lib/unmagic/browser/console/renderer.rb,
lib/unmagic/browser/console/terminal.rb,
lib/unmagic/browser/driver/cloudflare.rb,
lib/unmagic/browser/driver/connection.rb,
lib/unmagic/browser/driver/cloudflare/transport.rb

Overview

The class is declared before its parts are required, because they reopen it. Its documentation lives at the bottom of this file, with the implementation.

Defined Under Namespace

Classes: Browser