Class: Unmagic::Browser::Console::Document
- Defined in:
- lib/unmagic/browser/console/values.rb
Overview
Bytes there's no way to draw in a terminal — a PDF. Saved and pointed at.
Instance Attribute Summary collapse
-
#extension ⇒ String
readonly
The file extension for the copy written to disk.
Attributes inherited from Tagged
Instance Method Summary collapse
-
#initialize(value, extension: "pdf", name: "document") ⇒ Document
constructor
A new instance of Document.
Constructor Details
#initialize(value, extension: "pdf", name: "document") ⇒ Document
Returns a new instance of Document.
68 69 70 71 |
# File 'lib/unmagic/browser/console/values.rb', line 68 def initialize(value, extension: "pdf", name: "document") super(value, name: name) @extension = extension end |
Instance Attribute Details
#extension ⇒ String (readonly)
Returns the file extension for the copy written to disk.
74 75 76 |
# File 'lib/unmagic/browser/console/values.rb', line 74 def extension @extension end |